import pandas as pd
import sweetviz as sv
from pathlib import Path
import typer

app = typer.Typer()


@app.command()
def report(input_path: str):
    """Generates and render an HTML report of your dataset's EDA.

    Args:
        input_path (str): path to CSV input file.
    """
    # Get dataset name
    dataset_name = Path(input_path).stem.capitalize()

    # Read CSV file from the argument
    df = pd.read_csv(input_path)

    # Generate a reporte.
    report = sv.analyze([df, dataset_name])

    # Render HTML report in your default browser.
    report.show_html()


# -------------------- MORE FEATURES HERE, LATER -----------------
@app.command()
def compare(dataset1: str, dataset2: str):
    """Generate and render an EDA report for comparison of two datasets.

    Args:
        dataset1 (str): Path to main CSV file.
        dataset2 (str): Path to comparison CSV file.
    """

    # Read CSV files from the arguments
    df1, df2 = pd.read_csv(dataset1), pd.read_csv(dataset2)

    # Get dataset names
    dataset1_name, dataset2_name = (
        Path(dataset1).stem.capitalize(),
        Path(dataset2).stem.capitalize(),
    )

    # Generate a comparison report
    report = sv.compare([df1, dataset1_name], [df2, dataset2_name])

    # Render the HTML in your default browser
    report.show_html()


@app.command()
def target(input_path: str, target: str):
    """Generate and render an EDA report against a target variable.

    Args:
        input_path (str): Path to CSV data file
        target (str): Target variable.
    """

    # Read CSV file from the argument
    df = pd.read_csv(input_path)

    # Get dataset name
    dataset_name = Path(input_path).stem.capitalize()

    # Generate a reporte.
    report = sv.analyze([df, dataset_name], target)

    # Render HTML report in your default browser.
    report.show_html()


@app.command()
def compare_with_target(dataset1: str, dataset2: str, target: str):
    """Generate and render EDA report comparing two files against a target variable.

    Args:
        dataset1 (str): Path to main CSV dataset
        dataset2 (str): Path to comparison CSV Dataset
        target (str): Target variable name
    """

    # Read CSVs from arguments
    df1, df2 = pd.read_csv(dataset1), pd.read_csv(dataset2)

    # Get dataset names
    dataset1_name, dataset2_name = (
        Path(dataset1).stem.capitalize(),
        Path(dataset2).stem.capitalize(),
    )

    # Generate a comparison report against the target variable
    report = sv.compare([df1, dataset1_name], [df2, dataset2_name], target)

    # Render HTML report in your default browser
    report.show_html()


if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['python_eda']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.3.2,<2.0.0', 'sweetviz>=2.1.3,<3.0.0', 'typer[all]>=0.4.0,<0.5.0']

entry_points = \
{'console_scripts': ['pyeda = python_eda.main:app']}

setup_kwargs = {
    'name': 'python-eda',
    'version': '0.1.2',
    'description': 'A CLI wrapper for sweetviz Python exploratory data analysis (EDA) tool.',
    'long_description': '# Python EDA in CLI -- Exploratory Data Analysis in Command Line Interface\n\nThis project wraps the python exploratory data analysis tool sweetviz in a commandline interface.\n\n---\n## Installation\nYou can install this package with pip. It supports Python versions 3.6+.\n\n```shell\npip install python-eda\n```\n\n---\n## Usage\n\n### Generate report for a dataset\n\n```\npyeda report <path-to-dataset>\n```\n\n### Generate report for a dataset with a target variable\n\n```\npyeda target <path-to-dataset> <target-variable>\n```\n\n### Generate comparison report between two datasets\n\n```\npyeda compare <path-to-dataset1> <path-to-dataset2>\n```\n\n### Generate comparison report between two datasets with a target variable\n\n```\npyeda compare <path-to-dataset1> <path-to-dataset2> <target-variable>\n```\n\n---\n## Python EDA Illustration\nThe creation of this EDA is explained in the Towards data science post [Python Exploratory Data Analysis](https://towardsdatascience.com/how-to-do-a-ton-of-analysis-in-the-blink-of-an-eye-16fa9affce06)\n\nPackaging and distribution of this CLI EDA tool using Poetry, is explained in [You Are Not Still Using Virtualenv, Are You?](https://towardsdatascience.com/poetry-to-complement-virtualenv-44088cc78fd1)\n\nFor more interesting data science tactics please visit my [Medium profile](https://thuwarakesh.medium.com). ',
    'author': 'Thuwarakesh',
    'author_email': 'thuwarakesh@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ThuwarakeshM/python-eda',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
